from .structs import Pair

AAVE_CRO = Pair("AAVE_CRO", price_precision=2, quantity_precision=3)
AAVE_USDC = Pair("AAVE_USDC", price_precision=2, quantity_precision=4)
AAVE_USDT = Pair("AAVE_USDT", price_precision=3, quantity_precision=4)
ADA_BTC = Pair("ADA_BTC", price_precision=9, quantity_precision=0)
ADA_CRO = Pair("ADA_CRO", price_precision=3, quantity_precision=2)
ADA_USDC = Pair("ADA_USDC", price_precision=5, quantity_precision=1)
ADA_USDT = Pair("ADA_USDT", price_precision=5, quantity_precision=1)
AGLD_USDT = Pair("AGLD_USDT", price_precision=4, quantity_precision=2)
ALGO_BTC = Pair("ALGO_BTC", price_precision=8, quantity_precision=2)
ALGO_CRO = Pair("ALGO_CRO", price_precision=3, quantity_precision=2)
ALGO_USDC = Pair("ALGO_USDC", price_precision=4, quantity_precision=2)
ALGO_USDT = Pair("ALGO_USDT", price_precision=4, quantity_precision=2)
ALICE_USDT = Pair("ALICE_USDT", price_precision=3, quantity_precision=3)
AMP_USDT = Pair("AMP_USDT", price_precision=5, quantity_precision=1)
ANKR_USDT = Pair("ANKR_USDT", price_precision=6, quantity_precision=1)
ANY_USDT = Pair("ANY_USDT", price_precision=3, quantity_precision=3)
ARPA_USDC = Pair("ARPA_USDC", price_precision=5, quantity_precision=1)
AR_USDC = Pair("AR_USDC", price_precision=3, quantity_precision=3)
ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
ATOM_USDC = Pair("ATOM_USDC", price_precision=3, quantity_precision=3)
ATOM_USDT = Pair("ATOM_USDT", price_precision=3, quantity_precision=2)
AUDIO_USDT = Pair("AUDIO_USDT", price_precision=4, quantity_precision=2)
AVAX_BTC = Pair("AVAX_BTC", price_precision=7, quantity_precision=3)
AVAX_USDC = Pair("AVAX_USDC", price_precision=3, quantity_precision=3)
AVAX_USDT = Pair("AVAX_USDT", price_precision=3, quantity_precision=3)
AXS_BTC = Pair("AXS_BTC", price_precision=7, quantity_precision=3)
AXS_USDT = Pair("AXS_USDT", price_precision=4, quantity_precision=2)
BADGER_USDT = Pair("BADGER_USDT", price_precision=3, quantity_precision=3)
BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
BAND_CRO = Pair("BAND_CRO", price_precision=3, quantity_precision=2)
BAND_USDT = Pair("BAND_USDT", price_precision=4, quantity_precision=2)
BAT_CRO = Pair("BAT_CRO", price_precision=3, quantity_precision=2)
BAT_USDT = Pair("BAT_USDT", price_precision=4, quantity_precision=2)
BCH_BTC = Pair("BCH_BTC", price_precision=6, quantity_precision=3)
BCH_USDT = Pair("BCH_USDT", price_precision=2, quantity_precision=5)
BICO_USDT = Pair("BICO_USDT", price_precision=4, quantity_precision=2)
BNT_CRO = Pair("BNT_CRO", price_precision=3, quantity_precision=2)
BNT_USDT = Pair("BNT_USDT", price_precision=4, quantity_precision=3)
BOND_USDC = Pair("BOND_USDC", price_precision=3, quantity_precision=3)
BOSON_USDT = Pair("BOSON_USDT", price_precision=4, quantity_precision=2)
BRZ_USDT = Pair("BRZ_USDT", price_precision=5, quantity_precision=1)
BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
BTC_USDT = Pair("BTC_USDT", price_precision=2, quantity_precision=6)
C98_USDT = Pair("C98_USDT", price_precision=4, quantity_precision=2)
CELR_USDT = Pair("CELR_USDT", price_precision=6, quantity_precision=1)
CHR_USDT = Pair("CHR_USDT", price_precision=5, quantity_precision=1)
CHZ_BTC = Pair("CHZ_BTC", price_precision=10, quantity_precision=1)
CHZ_USDT = Pair("CHZ_USDT", price_precision=5, quantity_precision=2)
CKB_USDT = Pair("CKB_USDT", price_precision=6, quantity_precision=0)
COMP_CRO = Pair("COMP_CRO", price_precision=2, quantity_precision=3)
COMP_USDT = Pair("COMP_USDT", price_precision=2, quantity_precision=5)
COTI_USDC = Pair("COTI_USDC", price_precision=5, quantity_precision=1)
CQT_USDT = Pair("CQT_USDT", price_precision=4, quantity_precision=2)
CRO_BTC = Pair("CRO_BTC", price_precision=9, quantity_precision=2)
CRO_USDC = Pair("CRO_USDC", price_precision=5, quantity_precision=3)
CRO_USDT = Pair("CRO_USDT", price_precision=5, quantity_precision=3)
CRV_BTC = Pair("CRV_BTC", price_precision=8, quantity_precision=2)
CRV_CRO = Pair("CRV_CRO", price_precision=3, quantity_precision=2)
CRV_USDT = Pair("CRV_USDT", price_precision=4, quantity_precision=4)
CTSI_USDT = Pair("CTSI_USDT", price_precision=5, quantity_precision=1)
CVX_USDT = Pair("CVX_USDT", price_precision=3, quantity_precision=3)
DAI_CRO = Pair("DAI_CRO", price_precision=3, quantity_precision=3)
DAI_USDC = Pair("DAI_USDC", price_precision=4, quantity_precision=2)
DAI_USDT = Pair("DAI_USDT", price_precision=4, quantity_precision=3)
DAR_USDT = Pair("DAR_USDT", price_precision=4, quantity_precision=2)
DERC_USDC = Pair("DERC_USDC", price_precision=4, quantity_precision=2)
DERC_USDT = Pair("DERC_USDT", price_precision=4, quantity_precision=2)
DOGE_BTC = Pair("DOGE_BTC", price_precision=10, quantity_precision=1)
DOGE_USDC = Pair("DOGE_USDC", price_precision=5, quantity_precision=1)
DOGE_USDT = Pair("DOGE_USDT", price_precision=5, quantity_precision=2)
DOT_BTC = Pair("DOT_BTC", price_precision=7, quantity_precision=4)
DOT_CRO = Pair("DOT_CRO", price_precision=3, quantity_precision=3)
DOT_USDC = Pair("DOT_USDC", price_precision=3, quantity_precision=3)
DOT_USDT = Pair("DOT_USDT", price_precision=4, quantity_precision=3)
DYDX_BTC = Pair("DYDX_BTC", price_precision=8, quantity_precision=3)
DYDX_USDT = Pair("DYDX_USDT", price_precision=3, quantity_precision=3)
EFI_BTC = Pair("EFI_BTC", price_precision=9, quantity_precision=2)
EFI_USDT = Pair("EFI_USDT", price_precision=4, quantity_precision=2)
EGLD_CRO = Pair("EGLD_CRO", price_precision=3, quantity_precision=2)
EGLD_USDC = Pair("EGLD_USDC", price_precision=2, quantity_precision=4)
EGLD_USDT = Pair("EGLD_USDT", price_precision=4, quantity_precision=3)
ELON_USDT = Pair("ELON_USDT", price_precision=10, quantity_precision=0)
ENJ_BTC = Pair("ENJ_BTC", price_precision=9, quantity_precision=2)
ENJ_CRO = Pair("ENJ_CRO", price_precision=3, quantity_precision=2)
ENJ_USDC = Pair("ENJ_USDC", price_precision=4, quantity_precision=2)
ENJ_USDT = Pair("ENJ_USDT", price_precision=5, quantity_precision=1)
ENS_USDT = Pair("ENS_USDT", price_precision=3, quantity_precision=3)
EOS_BTC = Pair("EOS_BTC", price_precision=8, quantity_precision=2)
EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
EPS_USDT = Pair("EPS_USDT", price_precision=5, quantity_precision=1)
ETC_BTC = Pair("ETC_BTC", price_precision=7, quantity_precision=3)
ETC_USDT = Pair("ETC_USDT", price_precision=3, quantity_precision=3)
ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=5)
ETH_USDC = Pair("ETH_USDC", price_precision=2, quantity_precision=5)
ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
FARM_USDC = Pair("FARM_USDC", price_precision=2, quantity_precision=4)
FET_USDT = Pair("FET_USDT", price_precision=5, quantity_precision=1)
FIL_BTC = Pair("FIL_BTC", price_precision=7, quantity_precision=3)
FIL_USDT = Pair("FIL_USDT", price_precision=3, quantity_precision=3)
FLOW_USDC = Pair("FLOW_USDC", price_precision=4, quantity_precision=2)
FLOW_USDT = Pair("FLOW_USDT", price_precision=3, quantity_precision=4)
FORTH_USDT = Pair("FORTH_USDT", price_precision=3, quantity_precision=3)
FTM_BTC = Pair("FTM_BTC", price_precision=9, quantity_precision=2)
FTM_USDC = Pair("FTM_USDC", price_precision=4, quantity_precision=2)
FTM_USDT = Pair("FTM_USDT", price_precision=4, quantity_precision=2)
FXS_USDC = Pair("FXS_USDC", price_precision=4, quantity_precision=2)
GALA_BTC = Pair("GALA_BTC", price_precision=9, quantity_precision=1)
GALA_USDC = Pair("GALA_USDC", price_precision=5, quantity_precision=1)
GALA_USDT = Pair("GALA_USDT", price_precision=6, quantity_precision=0)
GHST_USDC = Pair("GHST_USDC", price_precision=4, quantity_precision=2)
GLM_USDT = Pair("GLM_USDT", price_precision=5, quantity_precision=1)
GODS_USDT = Pair("GODS_USDT", price_precision=4, quantity_precision=2)
GRT_CRO = Pair("GRT_CRO", price_precision=3, quantity_precision=2)
GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
GTC_USDT = Pair("GTC_USDT", price_precision=3, quantity_precision=3)
HBAR_BTC = Pair("HBAR_BTC", price_precision=10, quantity_precision=1)
HBAR_USDT = Pair("HBAR_USDT", price_precision=5, quantity_precision=1)
HNT_USDT = Pair("HNT_USDT", price_precision=3, quantity_precision=3)
HOD_USDT = Pair("HOD_USDT", price_precision=6, quantity_precision=0)
HOT_USDT = Pair("HOT_USDT", price_precision=6, quantity_precision=0)
ICP_BTC = Pair("ICP_BTC", price_precision=8, quantity_precision=0)
ICP_USDT = Pair("ICP_USDT", price_precision=3, quantity_precision=3)
ICX_BTC = Pair("ICX_BTC", price_precision=8, quantity_precision=1)
ICX_CRO = Pair("ICX_CRO", price_precision=3, quantity_precision=0)
ICX_USDT = Pair("ICX_USDT", price_precision=4, quantity_precision=2)
ILV_BTC = Pair("ILV_BTC", price_precision=6, quantity_precision=4)
ILV_USDT = Pair("ILV_USDT", price_precision=2, quantity_precision=4)
IMX_USDC = Pair("IMX_USDC", price_precision=4, quantity_precision=2)
INJ_USDT = Pair("INJ_USDT", price_precision=3, quantity_precision=3)
IOTX_USDC = Pair("IOTX_USDC", price_precision=6, quantity_precision=0)
IOTX_USDT = Pair("IOTX_USDT", price_precision=5, quantity_precision=1)
IQ_USDT = Pair("IQ_USDT", price_precision=6, quantity_precision=0)
JASMY_USDT = Pair("JASMY_USDT", price_precision=5, quantity_precision=1)
KAVA_USDT = Pair("KAVA_USDT", price_precision=4, quantity_precision=2)
KEEP_USDT = Pair("KEEP_USDT", price_precision=5, quantity_precision=1)
KLAY_USDT = Pair("KLAY_USDT", price_precision=4, quantity_precision=2)
KNC_USDT = Pair("KNC_USDT", price_precision=4, quantity_precision=3)
KSM_CRO = Pair("KSM_CRO", price_precision=2, quantity_precision=3)
KSM_USDC = Pair("KSM_USDC", price_precision=2, quantity_precision=4)
KSM_USDT = Pair("KSM_USDT", price_precision=3, quantity_precision=3)
LINK_BTC = Pair("LINK_BTC", price_precision=7, quantity_precision=2)
LINK_CRO = Pair("LINK_CRO", price_precision=2, quantity_precision=2)
LINK_USDC = Pair("LINK_USDC", price_precision=3, quantity_precision=3)
LINK_USDT = Pair("LINK_USDT", price_precision=3, quantity_precision=2)
LPT_USDC = Pair("LPT_USDC", price_precision=3, quantity_precision=3)
LRC_USDT = Pair("LRC_USDT", price_precision=5, quantity_precision=2)
LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
LTC_USDC = Pair("LTC_USDC", price_precision=2, quantity_precision=4)
LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
LUNA_BTC = Pair("LUNA_BTC", price_precision=7, quantity_precision=3)
LUNA_USDC = Pair("LUNA_USDC", price_precision=3, quantity_precision=3)
LUNA_USDT = Pair("LUNA_USDT", price_precision=4, quantity_precision=2)
MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
MANA_CRO = Pair("MANA_CRO", price_precision=3, quantity_precision=2)
MANA_USDC = Pair("MANA_USDC", price_precision=4, quantity_precision=2)
MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
MASK_USDT = Pair("MASK_USDT", price_precision=4, quantity_precision=2)
MATIC_BTC = Pair("MATIC_BTC", price_precision=9, quantity_precision=0)
MATIC_USDC = Pair("MATIC_USDC", price_precision=5, quantity_precision=1)
MATIC_USDT = Pair("MATIC_USDT", price_precision=5, quantity_precision=2)
MIR_USDT = Pair("MIR_USDT", price_precision=4, quantity_precision=2)
MKR_CRO = Pair("MKR_CRO", price_precision=2, quantity_precision=3)
MKR_USDT = Pair("MKR_USDT", price_precision=2, quantity_precision=6)
MLN_USDC = Pair("MLN_USDC", price_precision=3, quantity_precision=3)
NANO_USDT = Pair("NANO_USDT", price_precision=4, quantity_precision=2)
NEAR_BTC = Pair("NEAR_BTC", price_precision=8, quantity_precision=2)
NEAR_CRO = Pair("NEAR_CRO", price_precision=3, quantity_precision=2)
NEAR_USDC = Pair("NEAR_USDC", price_precision=3, quantity_precision=3)
NEAR_USDT = Pair("NEAR_USDT", price_precision=4, quantity_precision=2)
NEO_BTC = Pair("NEO_BTC", price_precision=7, quantity_precision=3)
NEO_CRO = Pair("NEO_CRO", price_precision=3, quantity_precision=2)
NEO_USDT = Pair("NEO_USDT", price_precision=3, quantity_precision=4)
NKN_USDT = Pair("NKN_USDT", price_precision=5, quantity_precision=1)
NMR_USDT = Pair("NMR_USDT", price_precision=3, quantity_precision=3)
NU_USDC = Pair("NU_USDC", price_precision=4, quantity_precision=2)
OCEAN_USDT = Pair("OCEAN_USDT", price_precision=4, quantity_precision=2)
OGN_USDT = Pair("OGN_USDT", price_precision=4, quantity_precision=2)
OMG_BTC = Pair("OMG_BTC", price_precision=8, quantity_precision=4)
OMG_USDT = Pair("OMG_USDT", price_precision=4, quantity_precision=4)
ONEINCH_USDT = Pair("1INCH_USDT", price_precision=4, quantity_precision=2)
ONE_BTC = Pair("ONE_BTC", price_precision=10, quantity_precision=1)
ONE_USDC = Pair("ONE_USDC", price_precision=5, quantity_precision=1)
ONE_USDT = Pair("ONE_USDT", price_precision=5, quantity_precision=1)
ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
ONT_USDT = Pair("ONT_USDT", price_precision=4, quantity_precision=2)
OXT_USDT = Pair("OXT_USDT", price_precision=5, quantity_precision=1)
PAXG_USDT = Pair("PAXG_USDT", price_precision=2, quantity_precision=5)
PENDLE_USDT = Pair("PENDLE_USDT", price_precision=5, quantity_precision=1)
PERP_USDT = Pair("PERP_USDT", price_precision=3, quantity_precision=3)
PLA_USDT = Pair("PLA_USDT", price_precision=5, quantity_precision=1)
POLS_USDT = Pair("POLS_USDT", price_precision=4, quantity_precision=2)
POLY_USDC = Pair("POLY_USDC", price_precision=5, quantity_precision=1)
POWR_USDT = Pair("POWR_USDT", price_precision=5, quantity_precision=1)
QI_USDT = Pair("QI_USDT", price_precision=5, quantity_precision=1)
QNT_USDC = Pair("QNT_USDC", price_precision=2, quantity_precision=4)
QNT_USDT = Pair("QNT_USDT", price_precision=2, quantity_precision=4)
QTUM_USDT = Pair("QTUM_USDT", price_precision=4, quantity_precision=4)
QUICK_USDT = Pair("QUICK_USDT", price_precision=2, quantity_precision=4)
RADAR_USDT = Pair("RADAR_USDT", price_precision=6, quantity_precision=0)
RAD_USDC = Pair("RAD_USDC", price_precision=3, quantity_precision=3)
RARI_USDC = Pair("RARI_USDC", price_precision=3, quantity_precision=3)
RARI_USDT = Pair("RARI_USDT", price_precision=3, quantity_precision=3)
REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
REQ_USDT = Pair("REQ_USDT", price_precision=5, quantity_precision=1)
RGT_USDC = Pair("RGT_USDC", price_precision=3, quantity_precision=3)
RLC_USDT = Pair("RLC_USDT", price_precision=3, quantity_precision=3)
RLY_USDT = Pair("RLY_USDT", price_precision=5, quantity_precision=2)
RNDR_USDT = Pair("RNDR_USDT", price_precision=4, quantity_precision=2)
RSR_USDT = Pair("RSR_USDT", price_precision=5, quantity_precision=1)
RUNE_USDT = Pair("RUNE_USDT", price_precision=3, quantity_precision=3)
SAND_USDC = Pair("SAND_USDC", price_precision=4, quantity_precision=2)
SAND_USDT = Pair("SAND_USDT", price_precision=5, quantity_precision=2)
SC_USDT = Pair("SC_USDT", price_precision=6, quantity_precision=0)
SDN_USDT = Pair("SDN_USDT", price_precision=4, quantity_precision=2)
SHIB_USDC = Pair("SHIB_USDC", price_precision=9, quantity_precision=0)
SHIB_USDT = Pair("SHIB_USDT", price_precision=9, quantity_precision=0)
SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
SLP_USDT = Pair("SLP_USDT", price_precision=5, quantity_precision=1)
SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
SOL_BTC = Pair("SOL_BTC", price_precision=7, quantity_precision=3)
SOL_USDC = Pair("SOL_USDC", price_precision=3, quantity_precision=3)
SOL_USDT = Pair("SOL_USDT", price_precision=3, quantity_precision=3)
SPELL_USDC = Pair("SPELL_USDC", price_precision=6, quantity_precision=0)
SRM_USDC = Pair("SRM_USDC", price_precision=4, quantity_precision=2)
STORJ_USDT = Pair("STORJ_USDT", price_precision=4, quantity_precision=2)
STRAX_USDT = Pair("STRAX_USDT", price_precision=4, quantity_precision=2)
STX_USDT = Pair("STX_USDT", price_precision=4, quantity_precision=2)
SUPER_USDT = Pair("SUPER_USDT", price_precision=4, quantity_precision=2)
SUSHI_BTC = Pair("SUSHI_BTC", price_precision=8, quantity_precision=2)
SUSHI_USDT = Pair("SUSHI_USDT", price_precision=3, quantity_precision=3)
TFUEL_USDT = Pair("TFUEL_USDT", price_precision=5, quantity_precision=1)
THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
TONIC_USDC = Pair("TONIC_USDC", price_precision=10, quantity_precision=0)
TRB_USDT = Pair("TRB_USDT", price_precision=3, quantity_precision=3)
TRIBE_USDT = Pair("TRIBE_USDT", price_precision=4, quantity_precision=2)
TRU_USDT = Pair("TRU_USDT", price_precision=5, quantity_precision=1)
UMA_USDT = Pair("UMA_USDT", price_precision=3, quantity_precision=4)
UNI_CRO = Pair("UNI_CRO", price_precision=3, quantity_precision=2)
UNI_USDC = Pair("UNI_USDC", price_precision=3, quantity_precision=3)
UNI_USDT = Pair("UNI_USDT", price_precision=4, quantity_precision=4)
USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
VET_BTC = Pair("VET_BTC", price_precision=10, quantity_precision=0)
VET_CRO = Pair("VET_CRO", price_precision=4, quantity_precision=0)
VET_USDC = Pair("VET_USDC", price_precision=6, quantity_precision=0)
VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
VTHO_USDT = Pair("VTHO_USDT", price_precision=6, quantity_precision=0)
VVS_USDC = Pair("VVS_USDC", price_precision=8, quantity_precision=0)
WAVES_USDT = Pair("WAVES_USDT", price_precision=3, quantity_precision=3)
WAXP_USDT = Pair("WAXP_USDT", price_precision=5, quantity_precision=1)
WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=6)
WBTC_USDC = Pair("WBTC_USDC", price_precision=2, quantity_precision=6)
WBTC_USDT = Pair("WBTC_USDT", price_precision=2, quantity_precision=6)
XLM_BTC = Pair("XLM_BTC", price_precision=9, quantity_precision=0)
XLM_USDT = Pair("XLM_USDT", price_precision=5, quantity_precision=1)
XRP_BTC = Pair("XRP_BTC", price_precision=9, quantity_precision=0)
XRP_CRO = Pair("XRP_CRO", price_precision=3, quantity_precision=0)
XRP_USDC = Pair("XRP_USDC", price_precision=5, quantity_precision=1)
XRP_USDT = Pair("XRP_USDT", price_precision=5, quantity_precision=1)
XTZ_BTC = Pair("XTZ_BTC", price_precision=8, quantity_precision=2)
XTZ_USDT = Pair("XTZ_USDT", price_precision=4, quantity_precision=2)
XYO_USDC = Pair("XYO_USDC", price_precision=6, quantity_precision=0)
XYO_USDT = Pair("XYO_USDT", price_precision=6, quantity_precision=0)
YFI_BTC = Pair("YFI_BTC", price_precision=4, quantity_precision=6)
YFI_USDT = Pair("YFI_USDT", price_precision=2, quantity_precision=6)
YGG_BTC = Pair("YGG_BTC", price_precision=8, quantity_precision=2)
YGG_USDT = Pair("YGG_USDT", price_precision=4, quantity_precision=2)
ZIL_USDT = Pair("ZIL_USDT", price_precision=5, quantity_precision=1)
ZRX_USDT = Pair("ZRX_USDT", price_precision=4, quantity_precision=2)


def all():
    return [
        value for name, value in globals().items()
        if isinstance(value, Pair)
    ]
